pub struct ContextAssembler;Implementations
Sourceimpl ContextAssembler
impl ContextAssembler
Sourcepub fn assemble(
fragments: Vec<ContextFragment>,
budget: &mut TokenBudget,
) -> Result<RenderedContext>
pub fn assemble( fragments: Vec<ContextFragment>, budget: &mut TokenBudget, ) -> Result<RenderedContext>
Pack the fragments into the remaining budget, highest priority first. Returns the fragments that fit, in the order they were originally given (priority is used for eviction, not reordering).