InjectionScreen

Trait InjectionScreen 

pub trait InjectionScreen: Send + Sync {
    // Required method
    fn screen(&self, text: &str) -> Option<String>;
}
Flags suspicious untrusted spans before they reach the model.

Required Methods

fn screen(&self, text: &str) -> Option<String>

Return a reason string if the span looks like an injection attempt.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors